==> ejc-sealm-impl-3.0.0-20220309.001629-53-sources.jar: com/ejianc/business/sealm/bean/YysqEntity.java <==
package com.ejianc.business.sealm.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 用印申请
 * 
 * @author generator
 * 
 */
 @TableName("t_seal_yysq")
public class YysqEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="sqdw_id")
    private Long sqdwId; // 申请单位id
    @TableField(value="sqdw_name")
    private String sqdwName; // 申请单位名称
    @TableField(value="sqxm_id")
    private Long sqxmId; // 申请项目id
    @TableField(value="sqxm_name")
    private String sqxmName; // 申请项目名称
    @TableField(value="sqr_id")
    private Long sqrId; // 申请人id
    @TableField(value="sqr_name")
    private String sqrName; // 申请人名称
    @TableField(value="yy_date")
    private java.util.Date yyDate; // 用印日期
    @TableField(value="yzsq_id")
    private Long yzsqId; // 印章申请id
    @TableField(value="yzlb_id")
    private Long yzlbId; // 印章类别id
    @TableField(value="yzlb_name")
    private String yzlbName; // 印章类别名称
    @TableField(value="yzjb_id")
    private Long yzjbId; // 印章级别id
    @TableField(value="yzjb_name")
    private String yzjbName; // 印章级别名称
    @TableField(value="yylx_id")
    private Long yylxId; // 用印类型id
    @TableField(value="yylx_name")
    private String yylxName; // 用印类型名称
    @TableField(value="zkbm_id")
    private Long zkbmId; // 业务主控部门id
    @TableField(value="zkbm_name")
    private String zkbmName; // 业务主控部门名称
    @TableField(value="fs")
    private Integer fs; // 份数（默认1）
    @TableField(value="yzm")
    private String yzm; // 验证码
    @TableField(value="yy_reason")
    private String yyReason; // 用印事由
    @TableField(value="yysx_id")
    private Long yysxId; // 用印事项id
    @TableField(value="yysx_name")
    private String yysxName; // 用印事项名称
    @TableField(value="yysx_code")
    private String yysxCode; // 用印事项code
    @TableField(value="yycs")
    private String yycs; // 用印次数
    @TableField(value="djlj")
    private String djlj; // 单据链接
    @TableField(value="message_from")
    private Integer messageFrom; // 单据来源（默认1）1自建0推送
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="sf_yzsq")
    private Integer sfYzsq; // 是否从印章申请同步，默认是0(1:是，0：否)
    @TableField(value="begin_date")
    private java.util.Date beginDate; // 开始日期
    @TableField(value="end_date")
    private java.util.Date endDate; // 结束日期
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改人
    @TableField(value="bid_id")
    private Long bidId; // 投标ID，关联字段
    @TableField(value="bid_code")
    private java.lang.String bidCode; // 投标编码
    @TableField(value="yzcyr_id")
    private Long yzcyrId; // 印章持有人id
    @TableField(value="yzcyr_name")
    private String yzcyrName; // 印章持有人名称
    @TableField(value="xgcs")
    private Integer xgcs; // 修改次数
    
    

    /**
     * 单据编码
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 申请单位id
     */
    public Long getSqdwId() {
        return sqdwId;
    }

    /**
     * 申请单位id
     */
    public void setSqdwId(Long sqdwId) {
        this.sqdwId = sqdwId;
    }
    /**
     * 申请单位名称
     */
    public String getSqdwName() {
        return sqdwName;
    }

    /**
     * 申请单位名称
     */
    public void setSqdwName(String sqdwName) {
        this.sqdwName = sqdwName;
    }
    /**
     * 申请项目id
     */
    public Long getSqxmId() {
        return sqxmId;
    }

    /**
     * 申请项目id
     */
    public void setSqxmId(Long sqxmId) {
        this.sqxmId = sqxmId;
    }
    /**
     * 申请项目名称
     */
    public String getSqxmName() {
        return sqxmName;
    }

    /**
     * 申请项目名称
     */
    public void setSqxmName(String sqxmName) {
        this.sqxmName = sqxmName;
    }
    /**
     * 申请人id
     */
    public Long getSqrId() {
        return sqrId;
    }

    /**
     * 申请人id
     */
    public void setSqrId(Long sqrId) {
        this.sqrId = sqrId;
    }
    /**
     * 申请人名称
     */
    public String getSqrName() {
        return sqrName;
    }

    /**
     * 申请人名称
     */
    public void setSqrName(String sqrName) {
        this.sqrName = sqrName;
    }
    /**
     * 用印日期
     */
    public java.util.Date getYyDate() {
        return yyDate;
    }

    /**
     * 用印日期
     */
    public void setYyDate(java.util.Date yyDate) {
        this.yyDate = yyDate;
    }
    /**
     * 印章申请id
     */
    public Long getYzsqId() {
        return yzsqId;
    }

    /**
     * 印章申请id
     */
    public void setYzsqId(Long yzsqId) {
        this.yzsqId = yzsqId;
    }
    /**
     * 印章类别id
     */
    public Long getYzlbId() {
        return yzlbId;
    }

    /**
     * 印章类别id
     */
    public void setYzlbId(Long yzlbId) {
        this.yzlbId = yzlbId;
    }
    /**
     * 印章类别名称
     */
    public String getYzlbName() {
        return yzlbName;
    }

    /**
     * 印章类别名称
     */
    public void setYzlbName(String yzlbName) {
        this.yzlbName = yzlbName;
    }
    /**
     * 印章级别id
     */
    public Long getYzjbId() {
        return yzjbId;
    }

    /**
     * 印章级别id
     */
    public void setYzjbId(Long yzjbId) {
        this.yzjbId = yzjbId;
    }
    /**
     * 印章级别名称
     */
    public String getYzjbName() {
        return yzjbName;
    }

    /**
     * 印章级别名称
     */
    public void setYzjbName(String yzjbName) {
        this.yzjbName = yzjbName;
    }
    /**
     * 用印类型id
     */
    public Long getYylxId() {
        return yylxId;
    }

    /**
     * 用印类型id
     */
    public void setYylxId(Long yylxId) {
        this.yylxId = yylxId;
    }
    /**
     * 用印类型名称
     */
    public String getYylxName() {
        return yylxName;
    }

    /**
     * 用印类型名称
     */
    public void setYylxName(String yylxName) {
        this.yylxName = yylxName;
    }
    /**
     * 业务主控部门id
     */
    public Long getZkbmId() {
        return zkbmId;
    }

    /**
     * 业务主控部门id
     */
    public void setZkbmId(Long zkbmId) {
        this.zkbmId = zkbmId;
    }
    /**
     * 业务主控部门名称
     */
    public String getZkbmName() {
        return zkbmName;
    }

    /**
     * 业务主控部门名称
     */
    public void setZkbmName(String zkbmName) {
        this.zkbmName = zkbmName;
    }
    /**
     * 份数（默认1）
     */
    public Integer getFs() {
        return fs;
    }

    /**
     * 份数（默认1）
     */
    public void setFs(Integer fs) {
        this.fs = fs;
    }
    /**
     * 验证码
     */
    public String getYzm() {
        return yzm;
    }

    /**
     * 验证码
     */
    public void setYzm(String yzm) {
        this.yzm = yzm;
    }
    /**
     * 用印事由
     */
    public String getYyReason() {
        return yyReason;
    }

    /**
     * 用印事由
     */
    public void setYyReason(String yyReason) {
        this.yyReason = yyReason;
    }

    /**
     * 用印事项id
     */
    public Long getYysxId() {
        return yysxId;
    }
    /**
     * 用印事项id
     */
    public void setYysxId(Long yysxId) {
        this.yysxId = yysxId;
    }
    /**
     * 用印事项name
     */
    public String getYysxName() {
        return yysxName;
    }
    /**
     * 用印事项name
     */
    public void setYysxName(String yysxName) {
        this.yysxName = yysxName;
    }
    /**
     * 用印事项code
     */

    public String getYysxCode() {
        return yysxCode;
    }
    /**
     * 用印事项code
     */
    public void setYysxCode(String yysxCode) {
        this.yysxCode = yysxCode;
    }

    /**
     * 用印次数
     */
    public String getYycs() {
        return yycs;
    }

    /**
     * 用印次数
     */
    public void setYycs(String yycs) {
        this.yycs = yycs;
    }
    /**
     * 单据链接
     */
    public String getDjlj() {
        return djlj;
    }

    /**
     * 单据链接
     */
    public void setDjlj(String djlj) {
        this.djlj = djlj;
    }
    /**
     * 单据来源（默认1）1自建0推送
     */
    public Integer getMessageFrom() {
        return messageFrom;
    }

    /**
     * 单据来源（默认1）1自建0推送
     */
    public void setMessageFrom(Integer messageFrom) {
        this.messageFrom = messageFrom;
    }
    /**
     * 备注
     */
    public String getRemark() {
        return remark;
    }

    /**
     * 备注
     */
    public void setRemark(String remark) {
        this.remark = remark;
    }
    /**
     * 组织id
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织id
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 是否从印章申请同步，默认是0(1:是，0：否)
     */
    public Integer getSfYzsq() {
        return sfYzsq;
    }

    /**
     * 是否从印章申请同步，默认是0(1:是，0：否)
     */
    public void setSfYzsq(Integer sfYzsq) {
        this.sfYzsq = sfYzsq;
    }
    /**
     * 开始日期
     */
    public java.util.Date getBeginDate() {
        return beginDate;
    }

    /**
     * 开始日期
     */
    public void setBeginDate(java.util.Date beginDate) {
        this.beginDate = beginDate;
    }
    /**
     * 结束日期
     */
    public java.util.Date getEndDate() {
        return endDate;
    }

    /**
     * 结束日期
     */
    public void setEndDate(java.util.Date endDate) {
        this.endDate = endDate;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 编制人
     */
    public String getCreateUserName() {
        return createUserName;
    }

    /**
     * 编制人
     */
    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    /**
     * 修改人
     */
    public String getUpdateUserName() {
        return updateUserName;
    }

    /**
     * 修改人
     */
    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    /**
     * 投标ID，关联字段
     */
    public Long getBidId() {
        return bidId;
    }

    /**
     * 投标ID，关联字段
     */
    public void setBidId(Long bidId) {
        this.bidId = bidId;
    }

    /**
     * 投标编码
     */
    public java.lang.String getBidCode() {
        return bidCode;
    }

    /**
     * 投标编码
     */
    public void setBidCode(java.lang.String bidCode) {
        this.bidCode = bidCode;
    }

    /**
     * 印章持有人id
     */
    public Long getYzcyrId() {
        return yzcyrId;
    }

    /**
     * 印章持有人id
     */
    public void setYzcyrId(Long yzcyrId) {
        this.yzcyrId = yzcyrId;
    }

    /**
     * 印章持有人名称
     */
    public String getYzcyrName() {
        return yzcyrName;
    }

    /**
     * 印章持有人名称
     */
    public void setYzcyrName(String yzcyrName) {
        this.yzcyrName = yzcyrName;
    }

    /**
     * 修改次数
     */
    public Integer getXgcs() {
        return xgcs;
    }

    /**
     * 修改次数
     */
    public void setXgcs(Integer xgcs) {
        this.xgcs = xgcs;
    }
    
}

==> ejc-sealm-impl-3.0.0-20220401.091921-65-sources.jar: com/ejianc/business/sealm/bean/YysqEntity.java <==
package com.ejianc.business.sealm.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 用印申请
 * 
 * @author generator
 * 
 */
 @TableName("t_seal_yysq")
public class YysqEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="sqdw_id")
    private Long sqdwId; // 申请单位id
    @TableField(value="sqdw_name")
    private String sqdwName; // 申请单位名称
    @TableField(value="sqxm_id")
    private Long sqxmId; // 申请项目id
    @TableField(value="sqxm_name")
    private String sqxmName; // 申请项目名称
    @TableField(value="sqr_id")
    private Long sqrId; // 申请人id
    @TableField(value="sqr_name")
    private String sqrName; // 申请人名称
    @TableField(value="yy_date")
    private java.util.Date yyDate; // 用印日期
    @TableField(value="yzsq_id")
    private Long yzsqId; // 印章申请id
    @TableField(value="yzlb_id")
    private Long yzlbId; // 印章类别id
    @TableField(value="yzlb_name")
    private String yzlbName; // 印章类别名称
    @TableField(value="yzjb_id")
    private Long yzjbId; // 印章级别id
    @TableField(value="yzjb_name")
    private String yzjbName; // 印章级别名称
    @TableField(value="yylx_id")
    private Long yylxId; // 用印类型id
    @TableField(value="yylx_name")
    private String yylxName; // 用印类型名称
    @TableField(value="zkbm_id")
    private Long zkbmId; // 业务主控部门id
    @TableField(value="zkbm_name")
    private String zkbmName; // 业务主控部门名称
    @TableField(value="fs")
    private Integer fs; // 份数（默认1）
    @TableField(value="yzm")
    private String yzm; // 验证码
    @TableField(value="yy_reason")
    private String yyReason; // 用印事由
    @TableField(value="yysx_id")
    private Long yysxId; // 用印事项id
    @TableField(value="yysx_name")
    private String yysxName; // 用印事项名称
    @TableField(value="yysx_code")
    private String yysxCode; // 用印事项code
    @TableField(value="yycs")
    private String yycs; // 用印次数
    @TableField(value="djlj")
    private String djlj; // 单据链接
    @TableField(value="message_from")
    private Integer messageFrom; // 单据来源（默认1）1自建0推送
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="sf_yzsq")
    private Integer sfYzsq; // 是否从印章申请同步，默认是0(1:是，0：否)
    @TableField(value="begin_date")
    private java.util.Date beginDate; // 开始日期
    @TableField(value="end_date")
    private java.util.Date endDate; // 结束日期
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改人
    @TableField(value="bid_id")
    private Long bidId; // 投标ID，关联字段
    @TableField(value="bid_code")
    private java.lang.String bidCode; // 投标编码
    @TableField(value="yzcyr_id")
    private Long yzcyrId; // 印章持有人id
    @TableField(value="yzcyr_name")
    private String yzcyrName; // 印章持有人名称
    @TableField(value="xgcs")
    private Integer xgcs; // 修改次数
    @TableField(value="yybd_id")
    private Long yybdId; // 记录用印事项选择的表单id,用于单据编号参照选择时区分
    @TableField(value="yzbh_id")
    private Long yzbhId; // 印章编号id
    @TableField(value="yzbh_code")
    private String yzbhCode; // 印章编号code，对应印章登记里的印章编号
    @TableField(value="yzbh_name")
    private String yzbhName; // 印章编号名称
    
    

    /**
     * 单据编码
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 申请单位id
     */
    public Long getSqdwId() {
        return sqdwId;
    }

    /**
     * 申请单位id
     */
    public void setSqdwId(Long sqdwId) {
        this.sqdwId = sqdwId;
    }
    /**
     * 申请单位名称
     */
    public String getSqdwName() {
        return sqdwName;
    }

    /**
     * 申请单位名称
     */
    public void setSqdwName(String sqdwName) {
        this.sqdwName = sqdwName;
    }
    /**
     * 申请项目id
     */
    public Long getSqxmId() {
        return sqxmId;
    }

    /**
     * 申请项目id
     */
    public void setSqxmId(Long sqxmId) {
        this.sqxmId = sqxmId;
    }
    /**
     * 申请项目名称
     */
    public String getSqxmName() {
        return sqxmName;
    }

    /**
     * 申请项目名称
     */
    public void setSqxmName(String sqxmName) {
        this.sqxmName = sqxmName;
    }
    /**
     * 申请人id
     */
    public Long getSqrId() {
        return sqrId;
    }

    /**
     * 申请人id
     */
    public void setSqrId(Long sqrId) {
        this.sqrId = sqrId;
    }
    /**
     * 申请人名称
     */
    public String getSqrName() {
        return sqrName;
    }

    /**
     * 申请人名称
     */
    public void setSqrName(String sqrName) {
        this.sqrName = sqrName;
    }
    /**
     * 用印日期
     */
    public java.util.Date getYyDate() {
        return yyDate;
    }

    /**
     * 用印日期
     */
    public void setYyDate(java.util.Date yyDate) {
        this.yyDate = yyDate;
    }
    /**
     * 印章申请id
     */
    public Long getYzsqId() {
        return yzsqId;
    }

    /**
     * 印章申请id
     */
    public void setYzsqId(Long yzsqId) {
        this.yzsqId = yzsqId;
    }
    /**
     * 印章类别id
     */
    public Long getYzlbId() {
        return yzlbId;
    }

    /**
     * 印章类别id
     */
    public void setYzlbId(Long yzlbId) {
        this.yzlbId = yzlbId;
    }
    /**
     * 印章类别名称
     */
    public String getYzlbName() {
        return yzlbName;
    }

    /**
     * 印章类别名称
     */
    public void setYzlbName(String yzlbName) {
        this.yzlbName = yzlbName;
    }
    /**
     * 印章级别id
     */
    public Long getYzjbId() {
        return yzjbId;
    }

    /**
     * 印章级别id
     */
    public void setYzjbId(Long yzjbId) {
        this.yzjbId = yzjbId;
    }
    /**
     * 印章级别名称
     */
    public String getYzjbName() {
        return yzjbName;
    }

    /**
     * 印章级别名称
     */
    public void setYzjbName(String yzjbName) {
        this.yzjbName = yzjbName;
    }
    /**
     * 用印类型id
     */
    public Long getYylxId() {
        return yylxId;
    }

    /**
     * 用印类型id
     */
    public void setYylxId(Long yylxId) {
        this.yylxId = yylxId;
    }
    /**
     * 用印类型名称
     */
    public String getYylxName() {
        return yylxName;
    }

    /**
     * 用印类型名称
     */
    public void setYylxName(String yylxName) {
        this.yylxName = yylxName;
    }
    /**
     * 业务主控部门id
     */
    public Long getZkbmId() {
        return zkbmId;
    }

    /**
     * 业务主控部门id
     */
    public void setZkbmId(Long zkbmId) {
        this.zkbmId = zkbmId;
    }
    /**
     * 业务主控部门名称
     */
    public String getZkbmName() {
        return zkbmName;
    }

    /**
     * 业务主控部门名称
     */
    public void setZkbmName(String zkbmName) {
        this.zkbmName = zkbmName;
    }
    /**
     * 份数（默认1）
     */
    public Integer getFs() {
        return fs;
    }

    /**
     * 份数（默认1）
     */
    public void setFs(Integer fs) {
        this.fs = fs;
    }
    /**
     * 验证码
     */
    public String getYzm() {
        return yzm;
    }

    /**
     * 验证码
     */
    public void setYzm(String yzm) {
        this.yzm = yzm;
    }
    /**
     * 用印事由
     */
    public String getYyReason() {
        return yyReason;
    }

    /**
     * 用印事由
     */
    public void setYyReason(String yyReason) {
        this.yyReason = yyReason;
    }

    /**
     * 用印事项id
     */
    public Long getYysxId() {
        return yysxId;
    }
    /**
     * 用印事项id
     */
    public void setYysxId(Long yysxId) {
        this.yysxId = yysxId;
    }
    /**
     * 用印事项name
     */
    public String getYysxName() {
        return yysxName;
    }
    /**
     * 用印事项name
     */
    public void setYysxName(String yysxName) {
        this.yysxName = yysxName;
    }
    /**
     * 用印事项code
     */

    public String getYysxCode() {
        return yysxCode;
    }
    /**
     * 用印事项code
     */
    public void setYysxCode(String yysxCode) {
        this.yysxCode = yysxCode;
    }

    /**
     * 用印次数
     */
    public String getYycs() {
        return yycs;
    }

    /**
     * 用印次数
     */
    public void setYycs(String yycs) {
        this.yycs = yycs;
    }
    /**
     * 单据链接
     */
    public String getDjlj() {
        return djlj;
    }

    /**
     * 单据链接
     */
    public void setDjlj(String djlj) {
        this.djlj = djlj;
    }
    /**
     * 单据来源（默认1）1自建0推送
     */
    public Integer getMessageFrom() {
        return messageFrom;
    }

    /**
     * 单据来源（默认1）1自建0推送
     */
    public void setMessageFrom(Integer messageFrom) {
        this.messageFrom = messageFrom;
    }
    /**
     * 备注
     */
    public String getRemark() {
        return remark;
    }

    /**
     * 备注
     */
    public void setRemark(String remark) {
        this.remark = remark;
    }
    /**
     * 组织id
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织id
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 是否从印章申请同步，默认是0(1:是，0：否)
     */
    public Integer getSfYzsq() {
        return sfYzsq;
    }

    /**
     * 是否从印章申请同步，默认是0(1:是，0：否)
     */
    public void setSfYzsq(Integer sfYzsq) {
        this.sfYzsq = sfYzsq;
    }
    /**
     * 开始日期
     */
    public java.util.Date getBeginDate() {
        return beginDate;
    }

    /**
     * 开始日期
     */
    public void setBeginDate(java.util.Date beginDate) {
        this.beginDate = beginDate;
    }
    /**
     * 结束日期
     */
    public java.util.Date getEndDate() {
        return endDate;
    }

    /**
     * 结束日期
     */
    public void setEndDate(java.util.Date endDate) {
        this.endDate = endDate;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 编制人
     */
    public String getCreateUserName() {
        return createUserName;
    }

    /**
     * 编制人
     */
    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    /**
     * 修改人
     */
    public String getUpdateUserName() {
        return updateUserName;
    }

    /**
     * 修改人
     */
    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    /**
     * 投标ID，关联字段
     */
    public Long getBidId() {
        return bidId;
    }

    /**
     * 投标ID，关联字段
     */
    public void setBidId(Long bidId) {
        this.bidId = bidId;
    }

    /**
     * 投标编码
     */
    public java.lang.String getBidCode() {
        return bidCode;
    }

    /**
     * 投标编码
     */
    public void setBidCode(java.lang.String bidCode) {
        this.bidCode = bidCode;
    }

    /**
     * 印章持有人id
     */
    public Long getYzcyrId() {
        return yzcyrId;
    }

    /**
     * 印章持有人id
     */
    public void setYzcyrId(Long yzcyrId) {
        this.yzcyrId = yzcyrId;
    }

    /**
     * 印章持有人名称
     */
    public String getYzcyrName() {
        return yzcyrName;
    }

    /**
     * 印章持有人名称
     */
    public void setYzcyrName(String yzcyrName) {
        this.yzcyrName = yzcyrName;
    }

    /**
     * 修改次数
     */
    public Integer getXgcs() {
        return xgcs;
    }

    /**
     * 修改次数
     */
    public void setXgcs(Integer xgcs) {
        this.xgcs = xgcs;
    }

    public Long getYybdId() {
        return yybdId;
    }

    public void setYybdId(Long yybdId) {
        this.yybdId = yybdId;
    }

    public Long getYzbhId() {
        return yzbhId;
    }

    public void setYzbhId(Long yzbhId) {
        this.yzbhId = yzbhId;
    }
    public String getYzbhCode() {
        return yzbhCode;
    }

    public void setYzbhCode(String yzbhCode) {
        this.yzbhCode = yzbhCode;
    }

    public String getYzbhName() {
        return yzbhName;
    }

    public void setYzbhName(String yzbhName) {
        this.yzbhName = yzbhName;
    }
    
}
